#!/usr/bin/env python

from app.Jobs.ExampleJob import ExampleJob

print('''
Instead of loading the app Container on main.py, you can use Jobs directly, since they already load the Container
''')

ExampleJob.dispatchSync('Running job')

ExampleJob.dispatch('Running job on queue')



import os
import unittest
from tempfile import gettempdir
from uuid import uuid4
from equipment.framework.Log.AbstractLog import AbstractLog
from equipment.framework.Log.LocalLog import LocalLog
from equipment.framework.tests.BaseTest import BaseTest


class test_LocalLog(BaseTest):
    def setUp(self):
        super().setUp()
        self.path = str(gettempdir()) + os.path.sep + \
            'app-' + str(uuid4()) + '.tmp'
        self.app.config().set('LOG_LOCAL', 'path', self.path)
        self.log = LocalLog(config=self.app.config())

    def test_extends_from_abstract_log(self):
        with self.app.log.override(self.log):
            self.assertTrue(
                isinstance(self.app.log(), AbstractLog)
            )

    def test_returns_none(self):
        with self.app.log.override(self.log):
            message = str(uuid4())

            self.assertIsNone(
                self.app.log().debug(message)
            )

            self.assertIsNone(
                self.app.log().info(message)
            )

            self.assertIsNone(
                self.app.log().warning(message)
            )

            self.assertIsNone(
                self.app.log().error(message)
            )

            self.assertIsNone(
                self.app.log().critical(message)
            )


if __name__ == '__main__':
    unittest.main()



import unittest
from shutil import move, rmtree
from os import getcwd, sep
from os.path import isdir, isfile
from tempfile import gettempdir
from datetime import datetime
from codecs import open as _open
from click.testing import CliRunner
from equipment.console.Commands.NewCommand import NewCommand
from equipment.console import new


class test_NewCommandTest(unittest.TestCase):
    def test_command_invoke(self):
        project = '__pycache__'  # ensure it is always ignored

        runner = CliRunner()
        result = runner.invoke(new, [project])
        self.assertTrue(result.exit_code == 0)

        rmtree(f'{getcwd()}{sep}{project}', ignore_errors=True)

    def test_command_class(self):
        project = '__pycache__'  # ensure it is always ignored
        full_path = f'{getcwd()}{sep}{project}'

        if isdir(full_path):
            move(full_path, f'{gettempdir()}{sep}{datetime.now()}{sep}{project}')  # nopep8

        self.assertFalse(isdir(full_path))

        self.assertIsNone(NewCommand(project).run())

        self.assertTrue(isdir(full_path))

        self.assertTrue(isfile(f'{full_path}{sep}.env'))

        requirements_file = f'{full_path}{sep}requirements.txt'

        self.assertTrue(isfile(requirements_file))

        with _open(requirements_file, 'r') as f:
            self.assertTrue('equipment==' in f.read())

        rmtree(full_path, ignore_errors=True)


if __name__ == '__main__':
    unittest.main()



from importlib import import_module
from typing import Any, NoReturn
from sys import exit as _exit, modules as _modules
from pprint import pformat
from dependency_injector.containers import Container


def app(name: str = 'app.App.Container') -> Container:
    resolved_module = module(name)
    return resolved_module.Container


def module(name: str, print_exception: bool = False) -> Any:
    try:
        return import_module(name) if name not in _modules else _modules[name]
    except Exception as e:
        print_if(print_exception, e)
        return None


def print_if(condition: bool, *args, **kwargs) -> None:
    if condition:
        print(*args, **kwargs)


def print_unless(condition: bool, *args, **kwargs) -> None:
    if not condition:
        print(*args, **kwargs)


def dump(*args, **kwargs) -> None:
    pformat(*args, **kwargs)


def dd(*args, **kwargs) -> NoReturn:
    dump(*args, **kwargs)
    _exit()



import abc


class AbstractStorage(abc.ABC):
    def path(self, file: str) -> str:
        raise NotImplementedError

    def write(self, file: str, data: str) -> bool:
        raise NotImplementedError

    def read(self, file: str) -> str:
        raise NotImplementedError

    def exists(self, file: str) -> bool:
        raise NotImplementedError

    def remove(self, file: str) -> bool:
        raise NotImplementedError



#!/usr/bin/env python

import sys
from inspect import getmembers
from os import getcwd
import click
from equipment.framework.helpers import module
from equipment.console.Commands.NewCommand import NewCommand


@click.group()
@click.version_option()
def main() -> None:
    pass  # @click decorators handle the commands defined on this file


@main.command()
@click.argument('name')
def new(name):
    NewCommand(name).run()


# Add project commands if available
sys.path.append(getcwd())
project_commands_module = module('app.Commands', print_exception=True)

if project_commands_module is not None:
    for member in getmembers(project_commands_module):
        if isinstance(member[1], click.Command):
            try:
                main.add_command(getattr(project_commands_module, member[0]))
            except Exception:
                pass

if __name__ == '__main__':
    main()



from dependency_injector.containers import DeclarativeContainer
from dependency_injector.providers import Singleton
from equipment.framework.Config.ConfigFactory import ConfigFactory
from equipment.framework.Environment.EnvironmentFactory import EnvironmentFactory
from equipment.framework.Log.LogFactory import LogFactory
from equipment.framework.Mail.MailFactory import MailFactory
from equipment.framework.Queue.QueueFactory import QueueFactory
from equipment.framework.Storage.StorageFactory import StorageFactory


class Container(DeclarativeContainer):
    environment = Singleton(EnvironmentFactory)
    config = Singleton(ConfigFactory, environment)
    log = Singleton(LogFactory, config)
    queue = Singleton(QueueFactory, config, log)
    storage = Singleton(StorageFactory, config, log)
    mail = Singleton(MailFactory, config, log)
